==> haskell-hslua-2.3.0-136-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua
version:              2.3.0
visibility:           public
id:                   hslua-2.3.0-CZaMshLCf4sDj94GwriBb5
key:                  hslua-2.3.0-CZaMshLCf4sDj94GwriBb5
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    HsLua provides wrappers and helpers
    to bridge Haskell and <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

    Example programs are can be found in the @hslua-examples@
    subdir of the project
    <https://github.com/hslua/hslua repository>.

category:             Foreign
abi:                  1307a75edc84908627ffca3305800258
exposed:              True
exposed-modules:
    HsLua,
    HsLua.Aeson from hslua-aeson-2.3.1-CmOlCQnfedirwjsouH56J:HsLua.Aeson,
    HsLua.Class.Exposable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Exposable,
    HsLua.Class.Invokable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Invokable,
    HsLua.Class.Peekable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Peekable,
    HsLua.Class.Pushable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Pushable,
    HsLua.Class.Util from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Util,
    HsLua.Core from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core,
    HsLua.Core.Error from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core.Error,
    HsLua.Core.Types from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core.Types,
    HsLua.Core.Utf8 from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core.Utf8,
    HsLua.Marshalling from hslua-marshalling-2.3.1-KUwWOcwaJ3JJFYl2tKRjzM:HsLua.Marshalling,
    HsLua.ObjectOrientation from hslua-objectorientation-2.3.0-319vgvjTLAMEFKBYcNrPmB:HsLua.ObjectOrientation,
    HsLua.Packaging from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging,
    HsLua.Packaging.Function from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging.Function,
    HsLua.Packaging.Module from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging.Module,
    HsLua.Packaging.Rendering from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging.Rendering,
    HsLua.Typing from hslua-typing-0.1.1-EvZGt34RGHzAAy9rwhTa4q:HsLua.Typing,
    HsLua.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua
hs-libraries:         HShslua-2.3.0-CZaMshLCf4sDj94GwriBb5
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-aeson-2.3.1-CmOlCQnfedirwjsouH56J
    hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL
    hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN
    hslua-marshalling-2.3.1-KUwWOcwaJ3JJFYl2tKRjzM
    hslua-objectorientation-2.3.0-319vgvjTLAMEFKBYcNrPmB
    hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN
    hslua-typing-0.1.1-EvZGt34RGHzAAy9rwhTa4q mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html:         /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-2.3.0-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua
version:              2.3.0
visibility:           public
id:                   hslua-2.3.0-8gu1RGeYAa65XyTdWxqNRJ
key:                  hslua-2.3.0-8gu1RGeYAa65XyTdWxqNRJ
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    HsLua provides wrappers and helpers
    to bridge Haskell and <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

    Example programs are can be found in the @hslua-examples@
    subdir of the project
    <https://github.com/hslua/hslua repository>.

category:             Foreign
abi:                  1b2046a5978b513a285900b66eec866a
exposed:              True
exposed-modules:
    HsLua,
    HsLua.Aeson from hslua-aeson-2.3.1-84fO2qfXFyLDM03fgFFGo8:HsLua.Aeson,
    HsLua.Class.Exposable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Exposable,
    HsLua.Class.Invokable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Invokable,
    HsLua.Class.Peekable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Peekable,
    HsLua.Class.Pushable from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Pushable,
    HsLua.Class.Util from hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL:HsLua.Class.Util,
    HsLua.Core from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core,
    HsLua.Core.Error from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core.Error,
    HsLua.Core.Types from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core.Types,
    HsLua.Core.Utf8 from hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN:HsLua.Core.Utf8,
    HsLua.Marshalling from hslua-marshalling-2.3.1-KUwWOcwaJ3JJFYl2tKRjzM:HsLua.Marshalling,
    HsLua.ObjectOrientation from hslua-objectorientation-2.3.0-319vgvjTLAMEFKBYcNrPmB:HsLua.ObjectOrientation,
    HsLua.Packaging from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging,
    HsLua.Packaging.Function from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging.Function,
    HsLua.Packaging.Module from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging.Module,
    HsLua.Packaging.Rendering from hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN:HsLua.Packaging.Rendering,
    HsLua.Typing from hslua-typing-0.1.1-EvZGt34RGHzAAy9rwhTa4q:HsLua.Typing,
    HsLua.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua
hs-libraries:         HShslua-2.3.0-8gu1RGeYAa65XyTdWxqNRJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-aeson-2.3.1-84fO2qfXFyLDM03fgFFGo8
    hslua-classes-2.3.0-C6MVaPYvdthFUjwefZyKZL
    hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN
    hslua-marshalling-2.3.1-KUwWOcwaJ3JJFYl2tKRjzM
    hslua-objectorientation-2.3.0-319vgvjTLAMEFKBYcNrPmB
    hslua-packaging-2.3.1-Esb9RSjho47FOfB2GovkQN
    hslua-typing-0.1.1-EvZGt34RGHzAAy9rwhTa4q mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html:         /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
